@@ -19,13 +19,8 @@ public:
     void addErrorLogEntry(const QString &log);
     void addTitleLogEntry(const QString &log);
     void addEndLineLogEntry();
+
 private:
-    enum LogType {
-        AddEndLine = 0,
-        AddInfo,
-        AddError,
-        AddTitle
-    };
+    enum LogType { AddEndLine = 0, AddInfo, AddError, AddTitle };
     void addLogLine(const QString &message, LogType type);
 };
-
