@@ -14,10 +14,7 @@ class PimDataExporterConsole : public QObject
 {
     Q_OBJECT
 public:
-    enum Mode {
-        Import = 0,
-        Export = 1
-    };
+    enum Mode { Import = 0, Export = 1 };
 
     explicit PimDataExporterConsole(QObject *parent = nullptr);
     ~PimDataExporterConsole() override;
@@ -57,4 +54,3 @@ private:
     Mode mMode = Import;
     bool mInProgress = false;
 };
-
