@@ -26,8 +26,8 @@ protected:
     virtual void convertCollectionListToRealPath(KConfigGroup &group, const QString &currentKey) = 0;
     void slotCheckBackupConfig();
     virtual void exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier) = 0;
-    virtual Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
-    virtual Q_REQUIRED_RESULT QString resourcePath(const QString &agentIdentifier, const QString &defaultPath) const = 0;
+    Q_REQUIRED_RESULT virtual QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
+    Q_REQUIRED_RESULT virtual QString resourcePath(const QString &agentIdentifier, const QString &defaultPath) const = 0;
     virtual void backupAddressBookResourceFile(const QString &agentIdentifier, const QString &defaultPath) = 0;
 
 private:
