@@ -7,15 +7,16 @@
 #include "importaddressbookjobinterface.h"
 #include "archivestorage.h"
 
-#include <KLocalizedString>
-#include <KConfigGroup>
-#include <KZip>
+#include <KArchive>
 #include <KArchiveEntry>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KZip>
 
-#include <QTimer>
-#include <QFile>
 #include <QDir>
+#include <QFile>
 #include <QStandardPaths>
+#include <QTimer>
 
 ImportAddressbookJobInterface::ImportAddressbookJobInterface(QObject *parent, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep)
     : AbstractImportExportJob(parent, archiveStorage, typeSelected, numberOfStep)
@@ -62,7 +63,9 @@ void ImportAddressbookJobInterface::slotNextStep()
     }
 }
 
-void ImportAddressbookJobInterface::addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings)
+void ImportAddressbookJobInterface::addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig,
+                                                                const QString &resourceName,
+                                                                QMap<QString, QVariant> &settings)
 {
     if (resourceName == QLatin1String("akonadi_vcard_resource")) {
         KConfigGroup general = resourceConfig->group(QStringLiteral("General"));
@@ -80,9 +83,9 @@ void ImportAddressbookJobInterface::addSpecificResourceSettings(const KSharedCon
 
 bool ImportAddressbookJobInterface::isAConfigFile(const QString &name) const
 {
-    return name.endsWith(QLatin1String("rc")) && (name.startsWith(QLatin1String("akonadi_vcarddir_resource_"))
-                                                  || name.startsWith(QLatin1String("akonadi_vcard_resource_"))
-                                                  || name.startsWith(QLatin1String("akonadi_contacts_resource_")));
+    return name.endsWith(QLatin1String("rc"))
+        && (name.startsWith(QLatin1String("akonadi_vcarddir_resource_")) || name.startsWith(QLatin1String("akonadi_vcard_resource_"))
+            || name.startsWith(QLatin1String("akonadi_contacts_resource_")));
 }
 
 void ImportAddressbookJobInterface::restoreConfig()
@@ -92,21 +95,17 @@ void ImportAddressbookJobInterface::restoreConfig()
     const QString kaddressbookStr(QStringLiteral("kaddressbookrc"));
     const KArchiveEntry *kaddressbookrcentry = mArchiveDirectory->entry(Utils::configsPath() + kaddressbookStr);
     if (kaddressbookrcentry && kaddressbookrcentry->isFile()) {
-      const auto kaddressbookrcFile =
-          static_cast<const KArchiveFile *>(kaddressbookrcentry);
-      const QString searchExistingFilerc = configLocation() + kaddressbookStr;
-      const QString installPathFilerc =
-          installConfigLocation() + kaddressbookStr;
+        const auto kaddressbookrcFile = static_cast<const KArchiveFile *>(kaddressbookrcentry);
+        const QString searchExistingFilerc = configLocation() + kaddressbookStr;
+        const QString installPathFilerc = installConfigLocation() + kaddressbookStr;
 
-      if (QFileInfo::exists(searchExistingFilerc)) {
-        if (overwriteConfigMessageBox(kaddressbookStr)) {
-          importkaddressBookConfig(kaddressbookrcFile, installPathFilerc,
-                                   kaddressbookStr, Utils::configsPath());
-        } // Else merge!
-      } else {
-        importkaddressBookConfig(kaddressbookrcFile, installPathFilerc,
-                                 kaddressbookStr, Utils::configsPath());
-      }
+        if (QFileInfo::exists(searchExistingFilerc)) {
+            if (overwriteConfigMessageBox(kaddressbookStr)) {
+                importkaddressBookConfig(kaddressbookrcFile, installPathFilerc, kaddressbookStr, Utils::configsPath());
+            } // Else merge!
+        } else {
+            importkaddressBookConfig(kaddressbookrcFile, installPathFilerc, kaddressbookStr, Utils::configsPath());
+        }
     }
     restoreUiRcFile(QStringLiteral("kaddressbookui.rc"), QStringLiteral("kaddressbook"));
     Q_EMIT info(i18n("Config restored."));
@@ -135,34 +134,24 @@ void ImportAddressbookJobInterface::importkaddressBookConfig(const KArchiveFile
     const QString cvsTemplateDirName = QStringLiteral("/kaddressbook/csv-templates/");
     const KArchiveEntry *csvtemplateEntry = mArchiveDirectory->entry(Utils::dataPath() + cvsTemplateDirName);
     if (csvtemplateEntry && csvtemplateEntry->isDirectory()) {
-      const auto csvTemplateDir =
-          static_cast<const KArchiveDirectory *>(csvtemplateEntry);
-      const QStringList lst = csvTemplateDir->entries();
-      for (const QString &entryName : lst) {
-        const KArchiveEntry *entry = csvTemplateDir->entry(entryName);
-        if (entry && entry->isFile()) {
-          const auto csvTemplateFile = static_cast<const KArchiveFile *>(entry);
-          const QString name = csvTemplateFile->name();
-          QString autocorrectionPath =
-              QStandardPaths::writableLocation(
-                  QStandardPaths::GenericDataLocation) +
-              cvsTemplateDirName;
-          if (QFileInfo::exists(autocorrectionPath)) {
-            if (overwriteConfigMessageBox(name)) {
-              copyToFile(csvTemplateFile,
-                         autocorrectionPath + QLatin1Char('/') + name, name,
-                         Utils::dataPath() + cvsTemplateDirName);
+        const auto csvTemplateDir = static_cast<const KArchiveDirectory *>(csvtemplateEntry);
+        const QStringList lst = csvTemplateDir->entries();
+        for (const QString &entryName : lst) {
+            const KArchiveEntry *entry = csvTemplateDir->entry(entryName);
+            if (entry && entry->isFile()) {
+                const auto csvTemplateFile = static_cast<const KArchiveFile *>(entry);
+                const QString name = csvTemplateFile->name();
+                QString autocorrectionPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + cvsTemplateDirName;
+                if (QFileInfo::exists(autocorrectionPath)) {
+                    if (overwriteConfigMessageBox(name)) {
+                        copyToFile(csvTemplateFile, autocorrectionPath + QLatin1Char('/') + name, name, Utils::dataPath() + cvsTemplateDirName);
+                    }
+                } else {
+                    autocorrectionPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + cvsTemplateDirName;
+                    copyToFile(csvTemplateFile, autocorrectionPath + QLatin1Char('/') + name, name, Utils::dataPath() + cvsTemplateDirName);
+                }
             }
-          } else {
-            autocorrectionPath = QStandardPaths::writableLocation(
-                                     QStandardPaths::GenericDataLocation) +
-                                 cvsTemplateDirName;
-            copyToFile(csvTemplateFile,
-                       autocorrectionPath + QLatin1Char('/') + name, name,
-                       Utils::dataPath() + cvsTemplateDirName);
-          }
         }
-      }
     }
 
     importDataSubdirectory(QStringLiteral("/kaddressbook/viewertemplates/"));
@@ -176,8 +165,7 @@ void ImportAddressbookJobInterface::restoreResources()
     setProgressDialogLabel(i18n("Restore resources..."));
     increaseProgressDialog();
     QStringList listResource;
-    listResource
-        << restoreResourceFile(QStringLiteral("akonadi_vcard_resource"), Utils::addressbookPath(), Utils::storeAddressbook());
+    listResource << restoreResourceFile(QStringLiteral("akonadi_vcard_resource"), Utils::addressbookPath(), Utils::storeAddressbook());
 
     if (!mListResourceFile.isEmpty()) {
         QDir dir(mTempDirName);
@@ -192,43 +180,36 @@ void ImportAddressbookJobInterface::restoreResources()
                 || value.akonadiConfigFile.contains(QLatin1String("akonadi_contacts_resource_"))) {
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
-                  const auto file =
-                      static_cast<const KArchiveFile *>(fileResouceEntry);
-                  copyArchiveFileTo(file, copyToDirName);
-                  QString resourceName(file->name());
+                    const auto file = static_cast<const KArchiveFile *>(fileResouceEntry);
+                    copyArchiveFileTo(file, copyToDirName);
+                    QString resourceName(file->name());
 
-                  QString filename(resourceName);
-                  KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(
-                      copyToDirName + QLatin1Char('/') + resourceName);
+                    QString filename(resourceName);
+                    KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
-                  // TODO fix default path ????? backupaddressbook ???
-                  const QString newUrl = adaptResourcePath(
-                      resourceConfig, Utils::storeAddressbook());
-                  QFileInfo newUrlInfo(newUrl);
-                  const QString dataFile = value.akonadiResources;
-                  const KArchiveEntry *dataResouceEntry =
-                      mArchiveDirectory->entry(dataFile);
-                  if (dataResouceEntry->isFile()) {
-                    const auto file =
-                        static_cast<const KArchiveFile *>(dataResouceEntry);
-                    // TODO  adapt directory name too
-                    extractZipFile(
-                        file, copyToDirName, newUrlInfo.path(),
-                        value.akonadiConfigFile.contains(
-                            QLatin1String("akonadi_contacts_resource_")));
-                  }
+                    // TODO fix default path ????? backupaddressbook ???
+                    const QString newUrl = adaptResourcePath(resourceConfig, Utils::storeAddressbook());
+                    QFileInfo newUrlInfo(newUrl);
+                    const QString dataFile = value.akonadiResources;
+                    const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
+                    if (dataResouceEntry->isFile()) {
+                        const auto fileEntry = static_cast<const KArchiveFile *>(dataResouceEntry);
+                        // TODO  adapt directory name too
+                        extractZipFile(fileEntry,
+                                       copyToDirName,
+                                       newUrlInfo.path(),
+                                       value.akonadiConfigFile.contains(QLatin1String("akonadi_contacts_resource_")));
+                    }
                     settings.insert(QStringLiteral("Path"), newUrl);
 
                     const QString agentConfigFile = value.akonadiAgentConfigFile;
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
-                          const auto file = static_cast<const KArchiveFile *>(
-                              akonadiAgentConfigEntry);
-                          copyArchiveFileTo(file, copyToDirName);
-                          resourceName = file->name();
-                          filename = Utils::akonadiAgentName(
-                              copyToDirName + QLatin1Char('/') + resourceName);
+                            const auto file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
+                            copyArchiveFileTo(file, copyToDirName);
+                            resourceName = file->name();
+                            filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                         }
                     }
                     QString instanceType;
@@ -250,6 +231,6 @@ void ImportAddressbookJobInterface::restoreResources()
     }
 
     Q_EMIT info(i18n("Resources restored."));
-    //It's maildir support. Need to add support
+    // It's maildir support. Need to add support
     synchronizeResource(listResource);
 }
