@@ -24,8 +24,8 @@ public:
 protected:
     void slotCheckBackupConfig();
     virtual void exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier) = 0;
-    virtual Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
-    virtual Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const = 0;
+    Q_REQUIRED_RESULT virtual QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
+    Q_REQUIRED_RESULT virtual QString resourcePath(const QString &identifier) const = 0;
     virtual void backupAlarmResourceFile(const QString &agentIdentifier, const QString &defaultPath) = 0;
     virtual void convertCollectionIdsToRealPath(KConfigGroup &selectFolderNoteGroup, const QString &selectFolderNoteGroupStr) = 0;
 
