@@ -10,9 +10,9 @@
 #include <PimCommonAkonadi/CreateResource>
 
 #include <KArchive>
+#include <KArchiveEntry>
 #include <KLocalizedString>
 #include <KZip>
-#include <KArchiveEntry>
 
 #include <QDir>
 #include <QFile>
@@ -59,8 +59,8 @@ void ImportAlarmJobInterface::slotNextStep()
 
 bool ImportAlarmJobInterface::isAConfigFile(const QString &name) const
 {
-    return name.endsWith(QLatin1String("rc")) && (name.contains(QLatin1String("akonadi_kalarm_resource_"))
-                                                  || name.contains(QLatin1String("akonadi_kalarm_dir_resource_")));
+    return name.endsWith(QLatin1String("rc"))
+        && (name.contains(QLatin1String("akonadi_kalarm_resource_")) || name.contains(QLatin1String("akonadi_kalarm_dir_resource_")));
 }
 
 QString ImportAlarmJobInterface::configLocation() const
@@ -80,19 +80,16 @@ void ImportAlarmJobInterface::restoreConfig()
     const QString kalarmStr(QStringLiteral("kalarmrc"));
     const KArchiveEntry *kalarmrcentry = mArchiveDirectory->entry(Utils::configsPath() + kalarmStr);
     if (kalarmrcentry && kalarmrcentry->isFile()) {
-      const auto kalarmrcFile =
-          static_cast<const KArchiveFile *>(kalarmrcentry);
-      const QString searchExistingkalarmrc = configLocation() + kalarmStr;
-      const QString installPathkalarmrc = installConfigLocation() + kalarmStr;
-      if (QFileInfo::exists(searchExistingkalarmrc)) {
-        if (overwriteConfigMessageBox(kalarmStr)) {
-          importkalarmConfig(kalarmrcFile, installPathkalarmrc, kalarmStr,
-                             Utils::configsPath());
+        const auto kalarmrcFile = static_cast<const KArchiveFile *>(kalarmrcentry);
+        const QString searchExistingkalarmrc = configLocation() + kalarmStr;
+        const QString installPathkalarmrc = installConfigLocation() + kalarmStr;
+        if (QFileInfo::exists(searchExistingkalarmrc)) {
+            if (overwriteConfigMessageBox(kalarmStr)) {
+                importkalarmConfig(kalarmrcFile, installPathkalarmrc, kalarmStr, Utils::configsPath());
+            }
+        } else {
+            importkalarmConfig(kalarmrcFile, installPathkalarmrc, kalarmStr, Utils::configsPath());
         }
-      } else {
-        importkalarmConfig(kalarmrcFile, installPathkalarmrc, kalarmStr,
-                           Utils::configsPath());
-      }
     }
     restoreUiRcFile(QStringLiteral("kalarmui.rc"), QStringLiteral("kalarm"));
     Q_EMIT info(i18n("Config restored."));
@@ -130,46 +127,37 @@ void ImportAlarmJobInterface::restoreResources()
                 || value.akonadiConfigFile.contains(QLatin1String("akonadi_kalarm_resource_"))) {
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
-                  const auto file =
-                      static_cast<const KArchiveFile *>(fileResouceEntry);
-                  copyArchiveFileTo(file, copyToDirName);
-                  QString resourceName(file->name());
+                    const auto file = static_cast<const KArchiveFile *>(fileResouceEntry);
+                    copyArchiveFileTo(file, copyToDirName);
+                    QString resourceName(file->name());
 
-                  QString filename(resourceName);
-                  // TODO adapt filename otherwise it will use all the time the
-                  // same filename.
-                  qCDebug(PIMDATAEXPORTERCORE_LOG) << " filename :" << filename;
+                    QString filename(resourceName);
+                    // TODO adapt filename otherwise it will use all the time the
+                    // same filename.
+                    qCDebug(PIMDATAEXPORTERCORE_LOG) << " filename :" << filename;
 
-                  KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(
-                      copyToDirName + QLatin1Char('/') + resourceName);
+                    KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
-                  const QString newUrl =
-                      adaptResourcePath(resourceConfig, Utils::storeAlarm());
-                  QFileInfo newUrlInfo(newUrl);
-                  const QString dataFile = value.akonadiResources;
-                  const KArchiveEntry *dataResouceEntry =
-                      mArchiveDirectory->entry(dataFile);
-                  bool isDirResource = value.akonadiConfigFile.contains(
-                      QLatin1String("akonadi_kalarm_dir_resource_"));
-                  if (dataResouceEntry->isFile()) {
-                    const auto file =
-                        static_cast<const KArchiveFile *>(dataResouceEntry);
-                    // TODO  adapt directory name too
-                    extractZipFile(file, copyToDirName, newUrlInfo.path(),
-                                   isDirResource);
-                  }
+                    const QString newUrl = adaptResourcePath(resourceConfig, Utils::storeAlarm());
+                    QFileInfo newUrlInfo(newUrl);
+                    const QString dataFile = value.akonadiResources;
+                    const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
+                    bool isDirResource = value.akonadiConfigFile.contains(QLatin1String("akonadi_kalarm_dir_resource_"));
+                    if (dataResouceEntry->isFile()) {
+                        const auto fileEntry = static_cast<const KArchiveFile *>(dataResouceEntry);
+                        // TODO  adapt directory name too
+                        extractZipFile(fileEntry, copyToDirName, newUrlInfo.path(), isDirResource);
+                    }
                     settings.insert(QStringLiteral("Path"), newUrl);
 
                     const QString agentConfigFile = value.akonadiAgentConfigFile;
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
                         if (akonadiAgentConfigEntry->isFile()) {
-                          const auto file = static_cast<const KArchiveFile *>(
-                              akonadiAgentConfigEntry);
-                          copyArchiveFileTo(file, copyToDirName);
-                          resourceName = file->name();
-                          filename = Utils::akonadiAgentName(
-                              copyToDirName + QLatin1Char('/') + resourceName);
+                            const auto file = static_cast<const KArchiveFile *>(akonadiAgentConfigEntry);
+                            copyArchiveFileTo(file, copyToDirName);
+                            resourceName = file->name();
+                            filename = Utils::akonadiAgentName(copyToDirName + QLatin1Char('/') + resourceName);
                         }
                     }
                     const QString archiveNameType = isDirResource ? QStringLiteral("akonadi_kalarm_dir_resource") : QStringLiteral("akonadi_kalarm_resource");
@@ -181,6 +169,6 @@ void ImportAlarmJobInterface::restoreResources()
             }
         }
     }
-    //It's maildir support. Need to add support
+    // It's maildir support. Need to add support
     synchronizeResource(listResource);
 }
