@@ -5,8 +5,8 @@
 */
 
 #pragma once
-#include <QObject>
 #include "pimdataexporter_export.h"
+#include <QObject>
 class KZip;
 
 class PIMDATAEXPORTER_EXPORT ArchiveStorage : public QObject
@@ -26,6 +26,5 @@ Q_SIGNALS:
     void error(const QString &);
 
 private:
-    KZip *mArchive = nullptr;
+    KZip *const mArchive;
 };
-
