@@ -6,8 +6,8 @@
 
 #pragma once
 
-#include "exportimportutil.h"
 #include "core/utils.h"
+#include "exportimportutil.h"
 
 #include "addressbook/importaddressbookjobinterface.h"
 
@@ -20,10 +20,12 @@ public:
 
 protected:
     Q_REQUIRED_RESULT Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) override;
-    Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false) override;
+    Q_REQUIRED_RESULT QString createResource(const QString &resources,
+                                             const QString &name,
+                                             const QMap<QString, QVariant> &settings,
+                                             bool synchronizeTree = false) override;
     void synchronizeResource(const QStringList &lst) override;
     Q_REQUIRED_RESULT QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) override;
     Q_REQUIRED_RESULT QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
     Q_REQUIRED_RESULT QString configLocation() const override;
 };
-
