@@ -5,8 +5,8 @@
 */
 
 #include "exportakregatorjobinterfacetest.h"
-#include "exportakregatorjobinterfacetestimpl.h"
 #include "archivestorage.h"
+#include "exportakregatorjobinterfacetestimpl.h"
 #include "testexportfile.h"
 #include <QTest>
 
@@ -23,7 +23,7 @@ void ExportAkregatorJobInterfaceTest::exportAkregator_data()
     QTest::addColumn<Utils::StoredTypes>("options");
     const QByteArray pathConfig(QByteArray(PIMDATAEXPORTER_DIR) + "/export/");
     Utils::StoredTypes options = {Utils::StoredType::Config};
-    //TODO
+    // TODO
     options = {Utils::StoredType::Config | Utils::StoredType::Resources};
     QTest::newRow("fullresource") << pathConfig + QByteArray("fullresource/") << options;
 }
@@ -32,11 +32,10 @@ void ExportAkregatorJobInterfaceTest::exportAkregator()
 {
     QFETCH(QByteArray, configpath);
     QFETCH(Utils::StoredTypes, options);
-    auto file = new TestExportFile(this);
+    std::unique_ptr<TestExportFile> file{new TestExportFile(this)};
     file->setPathConfig(configpath);
 
-    auto exportAkregator = new ExportAkregatorJobInterfaceTestImpl(
-        this, options, file->archiveStorage(), 1);
+    auto exportAkregator = new ExportAkregatorJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     file->setAbstractImportExportJob(exportAkregator);
     file->start();
     delete exportAkregator;
