@@ -5,11 +5,11 @@
 */
 
 #include "exportcalendarsjobinterfacetest.h"
-#include "exportcalendarsjobinterfacetestimpl.h"
 #include "archivestorage.h"
+#include "exportcalendarsjobinterfacetestimpl.h"
 #include "testexportfile.h"
 #include <QTest>
-
+#include <memory>
 QTEST_MAIN(ExportCalendarsJobInterfaceTest)
 
 ExportCalendarsJobInterfaceTest::ExportCalendarsJobInterfaceTest(QObject *parent)
@@ -24,7 +24,7 @@ void ExportCalendarsJobInterfaceTest::exportCalendar_data()
     Utils::StoredTypes options = {Utils::StoredType::Config};
     const QByteArray pathConfig(QByteArray(PIMDATAEXPORTER_DIR) + "/export/");
     QTest::newRow("calendaronlyconfig") << pathConfig + QByteArray("calendaronlyconfig/") << options;
-    options = {Utils::StoredType::Config|Utils::StoredType::Resources};
+    options = {Utils::StoredType::Config | Utils::StoredType::Resources};
     QTest::newRow("calendarconfigandresources") << pathConfig + QByteArray("calendarconfigandresources/") << options;
 }
 
@@ -32,22 +32,23 @@ void ExportCalendarsJobInterfaceTest::exportCalendar()
 {
     QFETCH(QByteArray, configpath);
     QFETCH(Utils::StoredTypes, options);
-    auto file = new TestExportFile(this);
+    std::unique_ptr<TestExportFile> file{new TestExportFile(this)};
     file->setPathConfig(configpath);
     QVector<Utils::AkonadiInstanceInfo> lstInfo;
     Utils::AkonadiInstanceInfo info;
-    info.identifier = QLatin1String("akonadi_icaldir_resource_1");
+    info.identifier = QStringLiteral("akonadi_icaldir_resource_1");
     lstInfo << info;
-    info.identifier = QLatin1String("akonadi_ical_resource_2");
+    info.identifier = QStringLiteral("akonadi_ical_resource_2");
     lstInfo << info;
-    //Add extra resource.
-    info.identifier = QLatin1String("akonadi_contacts_resource_1");
+    info.identifier = QStringLiteral("akonadi_davgroupware_resource_0");
+    lstInfo << info;
+    // Add extra resource.
+    info.identifier = QStringLiteral("akonadi_contacts_resource_1");
     lstInfo << info;
     info.identifier = QStringLiteral("akonadi_kontact_resource_2");
     lstInfo << info;
 
-    auto exportNote = new ExportCalendarsJobInterfaceTestImpl(
-        this, options, file->archiveStorage(), 1);
+    auto exportNote = new ExportCalendarsJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     exportNote->setListOfResource(lstInfo);
     exportNote->setPathConfig(QLatin1String(configpath));
     file->setAbstractImportExportJob(exportNote);
