@@ -6,8 +6,8 @@
 
 #pragma once
 
-#include "exportimportutil.h"
 #include "core/utils.h"
+#include "exportimportutil.h"
 #include "notes/exportnotesjobinterface.h"
 
 #include <KConfigGroup>
@@ -26,6 +26,8 @@ protected:
     Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() override;
     Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const override;
     Q_REQUIRED_RESULT QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) override;
-    Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree) override;
+    Q_REQUIRED_RESULT QString createResource(const QString &resources,
+                                             const QString &name,
+                                             const QMap<QString, QVariant> &settings,
+                                             bool synchronizeTree) override;
 };
-
