@@ -5,21 +5,21 @@
 */
 
 #include "testexportfile.h"
+#include "abstractimportexportjob.h"
 #include "archivestorage.h"
 #include "compareexportfile.h"
-#include "abstractimportexportjob.h"
 #include "utils.h"
 
-#include <QTemporaryFile>
 #include <QDir>
 #include <QSignalSpy>
+#include <QTemporaryFile>
 #include <QTest>
 //#define REMOVE_CREATED_ZIP_FILE 1
 
 TestExportFile::TestExportFile(QObject *parent)
     : QObject(parent)
+    , mTemporaryFile(QDir::tempPath() + QStringLiteral("/archive.zip"))
 {
-    mTemporaryFile = QDir::tempPath() + QStringLiteral("/archive.zip");
     mArchiveStorage = new ArchiveStorage(mTemporaryFile, this);
     Q_ASSERT(mArchiveStorage->openArchive(true));
 }
@@ -50,12 +50,12 @@ void TestExportFile::setAbstractImportExportJob(AbstractImportExportJob *abstrac
 
 void TestExportFile::start()
 {
-    //Don't use setTestModeEnabled otherwise we can set env
-    //QStandardPaths::setTestModeEnabled(true);
+    // Don't use setTestModeEnabled otherwise we can set env
+    // QStandardPaths::setTestModeEnabled(true);
     qputenv("XDG_DATA_HOME", mPathConfig + "/share");
     qputenv("XDG_CONFIG_HOME", mPathConfig + "/config");
 
-    //TODO fix file name.
+    // TODO fix file name.
     Utils::addVersion(mArchiveStorage->archive());
     QTemporaryFile exportedFileInfoDummy;
     exportedFileInfoDummy.open();
@@ -77,6 +77,7 @@ void TestExportFile::start()
     compareExportFile.setTempFilePath(mTemporaryFile);
     compareExportFile.setListFilePath(QLatin1String(mPathConfig));
     compareExportFile.compareFiles();
+    qDebug() << " mTemporaryFile : " << mTemporaryFile;
 #ifdef REMOVE_CREATED_ZIP_FILE
     QVERIFY(QFile(mTemporaryFile).remove());
 #endif
