@@ -13,8 +13,7 @@ class UtilsTest : public QObject
     Q_OBJECT
 public:
     explicit UtilsTest(QObject *parent = nullptr);
-    ~UtilsTest() = default;
+    ~UtilsTest() override = default;
 private Q_SLOTS:
     void shouldTestValue();
 };
-
