@@ -8,12 +8,12 @@
 
 #include <KLocalizedString>
 
-#include <QTemporaryFile>
 #include <KConfigGroup>
+#include <QTemporaryFile>
 
-#include <QTimer>
-#include <QFile>
 #include <QColor>
+#include <QFile>
+#include <QTimer>
 #include <resourceconverterimpl.h>
 
 #include <QFileInfo>
@@ -61,6 +61,15 @@ void ExportCalendarJobInterface::slotWriteNextArchiveResource()
         } else if (identifier.contains(QLatin1String("akonadi_ical_resource_"))) {
             backupCalendarResourceFile(identifier, Utils::calendarPath());
             QTimer::singleShot(0, this, &ExportCalendarJobInterface::slotCalendarJobTerminated);
+        } else if (identifier.contains(QLatin1String("akonadi_davgroupware_resource_"))) {
+            backupCalendarResourceFile(identifier, Utils::calendarPath());
+            QTimer::singleShot(0, this, &ExportCalendarJobInterface::slotCalendarJobTerminated);
+        } else if (identifier.contains(QLatin1String("akonadi_openxchange_resource_"))) {
+            backupCalendarResourceFile(identifier, Utils::calendarPath());
+            QTimer::singleShot(0, this, &ExportCalendarJobInterface::slotCalendarJobTerminated);
+        } else if (identifier.contains(QLatin1String("akonadi_google_resource_"))) {
+            backupCalendarResourceFile(identifier, Utils::calendarPath());
+            QTimer::singleShot(0, this, &ExportCalendarJobInterface::slotCalendarJobTerminated);
         } else {
             QTimer::singleShot(0, this, &ExportCalendarJobInterface::slotCalendarJobTerminated);
         }
