@@ -23,11 +23,11 @@ public:
 
 protected:
     void slotCheckBackupConfig();
-    virtual Q_REQUIRED_RESULT QString convertToFullCollectionPath(const qlonglong collectionValue) = 0;
+    Q_REQUIRED_RESULT virtual QString convertToFullCollectionPath(const qlonglong collectionValue) = 0;
     virtual void convertCollectionListToRealPath(KConfigGroup &group, const QString &currentKey) = 0;
     virtual void exportResourceToArchive(const QString &archivePath, const QString &url, const QString &identifier) = 0;
-    virtual Q_REQUIRED_RESULT QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
-    virtual Q_REQUIRED_RESULT QString resourcePath(const QString &identifier) const = 0;
+    Q_REQUIRED_RESULT virtual QVector<Utils::AkonadiInstanceInfo> listOfResource() = 0;
+    Q_REQUIRED_RESULT virtual QString resourcePath(const QString &identifier) const = 0;
     virtual void backupCalendarResourceFile(const QString &agentIdentifier, const QString &defaultPath) = 0;
 
 private:
