@@ -8,17 +8,20 @@
 
 #include "importmailjobinterface.h"
 #include "pimdataexportercore_private_export.h"
-#include <AkonadiCore/Collection>
+#include <Akonadi/Collection>
 #include <Akonadi/KMime/SpecialMailCollections>
-#include <QStringList>
-#include <QHash>
 #include <KArchive>
+#include <QHash>
+#include <QStringList>
+#include <MailTransport/TransportManager>
 class ArchiveStorage;
-namespace KIdentityManagement {
+namespace KIdentityManagement
+{
 class Identity;
 class IdentityManager;
 }
-namespace MailTransport {
+namespace MailTransport
+{
 class Transport;
 }
 class PIMDATAEXPORTER_TESTS_EXPORT ImportMailJobInterfaceImpl : public ImportMailJobInterface
@@ -27,9 +30,13 @@ class PIMDATAEXPORTER_TESTS_EXPORT ImportMailJobInterfaceImpl : public ImportMai
 public:
     explicit ImportMailJobInterfaceImpl(QObject *widget, Utils::StoredTypes typeSelected, ArchiveStorage *archiveStorage, int numberOfStep);
     ~ImportMailJobInterfaceImpl() override;
+
 protected:
     void registerSpecialCollection(Akonadi::SpecialMailCollections::Type type, qint64 colId) override;
-    Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false) override;
+    Q_REQUIRED_RESULT QString createResource(const QString &resources,
+                                             const QString &name,
+                                             const QMap<QString, QVariant> &settings,
+                                             bool synchronizeTree = false) override;
     Q_REQUIRED_RESULT QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData) override;
     void synchronizeResource(const QStringList &lst) override;
     void importFilters(const QString &filename) override;
@@ -40,8 +47,9 @@ protected:
     void importSmtpMailTransport(const SmtpMailTransport &smtpMailTransport, int defaultTransport, int transportId) override;
     void addMailTransport(MailTransport::Transport *mt, int defaultTransport, int transportId);
     Q_REQUIRED_RESULT QString configLocation() const override;
+
 private:
+    Q_REQUIRED_RESULT int convertEncryptionEnum(int val);
     Q_REQUIRED_RESULT QString uniqueIdentityName(const QString &name);
     KIdentityManagement::IdentityManager *const mIdentityManager;
 };
-
