@@ -23,11 +23,11 @@ public:
     Q_REQUIRED_RESULT QString resourcePath(const QString &agentIdentifier, const QString &defaultPath = QString());
     Q_REQUIRED_RESULT QString adaptResourcePath(const KSharedConfigPtr &resourceConfig, const QString &storedData);
     Q_REQUIRED_RESULT QString resourcePath(const KSharedConfigPtr &resourceConfig, const QString &defaultPath = QString());
-    virtual Q_REQUIRED_RESULT QString changeResourcePath(QString url) const;
+    Q_REQUIRED_RESULT virtual QString changeResourcePath(QString url) const;
 
-    virtual Q_REQUIRED_RESULT QString convertToFullCollectionPath(const qlonglong collectionValue) = 0;
-    virtual Q_REQUIRED_RESULT Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) = 0;
+    Q_REQUIRED_RESULT virtual QString convertToFullCollectionPath(const qlonglong collectionValue) = 0;
+    Q_REQUIRED_RESULT virtual Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) = 0;
     Q_REQUIRED_RESULT QString storeResources(KZip *archive, const QString &identifier, const QString &path);
-    virtual Q_REQUIRED_RESULT QString installDefaultDirectory() = 0;
+    Q_REQUIRED_RESULT virtual QString installDefaultDirectory() = 0;
     virtual QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) = 0;
 };
