@@ -6,16 +6,16 @@
 
 #pragma once
 
+#include "pimdataexporter_export.h"
 #include <QObject>
 #include <QStringList>
-#include "pimdataexporter_export.h"
 class KJob;
 class PIMDATAEXPORTER_EXPORT SynchronizeResourceJob : public QObject
 {
     Q_OBJECT
 public:
     explicit SynchronizeResourceJob(QObject *parent = nullptr);
-    ~SynchronizeResourceJob();
+    ~SynchronizeResourceJob() override;
 
     void start();
     void setListResources(const QStringList &resources);
@@ -34,4 +34,3 @@ private:
     int mIndex = 0;
     bool mOnlyCollection = true;
 };
-
