@@ -7,7 +7,8 @@
 #pragma once
 
 #include <QDialog>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 class BackupFileStructureInfoDialog : public QDialog
@@ -21,6 +22,5 @@ private:
     void readConfig();
     void writeConfig();
     void loadStructure();
-    KPIMTextEdit::PlainTextEditorWidget *mEditor = nullptr;
+    KPIMTextEdit::PlainTextEditorWidget *const mEditor;
 };
-
