@@ -8,7 +8,8 @@
 
 #include <KPageDialog>
 #ifdef WITH_KUSERFEEDBACK
-namespace KUserFeedback {
+namespace KUserFeedback
+{
 class FeedbackConfigWidget;
 }
 #endif
@@ -25,9 +26,8 @@ private:
     void readConfig();
     void writeConfig();
 
-    PimDataExporterConfigureWidget *mConfigureWidget = nullptr;
+    PimDataExporterConfigureWidget *const mConfigureWidget;
 #ifdef WITH_KUSERFEEDBACK
     KUserFeedback::FeedbackConfigWidget *mUserFeedbackWidget = nullptr;
 #endif
 };
-
