@@ -21,9 +21,7 @@ public:
     explicit ShowArchiveStructureDialog(const QString &filename, QWidget *parent = nullptr);
     ~ShowArchiveStructureDialog() override;
 
-    enum File {
-        FullPath = Qt::UserRole + 1
-    };
+    enum File { FullPath = Qt::UserRole + 1 };
 
 private:
     void slotExportAsLogFile();
@@ -40,10 +38,9 @@ private:
     QTreeWidgetItem *addItem(QTreeWidgetItem *parent, const QString &name, const QString &fillFullPath);
     QString mFileName;
     QString mLogFile;
-    QTreeWidget *mTreeWidget = nullptr;
-    QPushButton *mExtractFile = nullptr;
-    QPushButton *mOpenFile = nullptr;
+    QTreeWidget *const mTreeWidget;
+    QPushButton *const mExtractFile;
+    QPushButton *const mOpenFile;
     KZip *mZip = nullptr;
     QTemporaryDir *mTempDir = nullptr;
 };
-
