@@ -5,19 +5,20 @@
 */
 
 #include "synchronizeresourcedialog.h"
-#include <KLocalizedString>
 #include <KListWidgetSearchLine>
+#include <KLocalizedString>
 
-#include <QPushButton>
-#include <QDialogButtonBox>
-#include <QVBoxLayout>
-#include <QListWidget>
-#include <QLabel>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <QDialogButtonBox>
+#include <QLabel>
+#include <QListWidget>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 SynchronizeResourceDialog::SynchronizeResourceDialog(QWidget *parent)
     : QDialog(parent)
+    , mListResourceWidget(new QListWidget(this))
 {
     setWindowTitle(i18nc("@title:window", "Synchronize Resources"));
     auto topLayout = new QVBoxLayout(this);
@@ -31,10 +32,8 @@ SynchronizeResourceDialog::SynchronizeResourceDialog(QWidget *parent)
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
-    mListResourceWidget = new QListWidget(this);
     mListResourceWidget->setObjectName(QStringLiteral("listresourcewidget"));
-    auto listWidgetSearchLine =
-        new KListWidgetSearchLine(this, mListResourceWidget);
+    auto listWidgetSearchLine = new KListWidgetSearchLine(this, mListResourceWidget);
     listWidgetSearchLine->setObjectName(QStringLiteral("listwidgetsearchline"));
 
     auto hbox = new QHBoxLayout;
