@@ -6,10 +6,10 @@
 
 #include "importexportprogressindicatorgui.h"
 #include "pimdataexporterglobalconfig.h"
-#include <QProgressDialog>
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <KStandardGuiItem>
+#include <QProgressDialog>
 
 ImportExportProgressIndicatorGui::ImportExportProgressIndicatorGui(QWidget *parentWidget, QObject *parent)
     : ImportExportProgressIndicatorBase(parent)
@@ -62,7 +62,10 @@ int ImportExportProgressIndicatorGui::mergeConfigMessageBox(const QString &confi
     if (PimDataExportGlobalConfig::self()->alwaysMergeConfigFile()) {
         return KMessageBox::Yes;
     }
-    return KMessageBox::warningYesNoCancel(mParentWidget, i18n("\"%1\" already exists. Do you want to overwrite it or merge it?", configName), i18n("Restore"), KStandardGuiItem::overwrite(),
+    return KMessageBox::warningYesNoCancel(mParentWidget,
+                                           i18n("\"%1\" already exists. Do you want to overwrite it or merge it?", configName),
+                                           i18n("Restore"),
+                                           KStandardGuiItem::overwrite(),
                                            KGuiItem(i18n("Merge")));
 }
 
@@ -71,7 +74,12 @@ bool ImportExportProgressIndicatorGui::overwriteConfigMessageBox(const QString &
     if (PimDataExportGlobalConfig::self()->alwaysOverrideFile()) {
         return true;
     }
-    return KMessageBox::warningYesNo(mParentWidget, i18n("\"%1\" already exists. Do you want to overwrite it?", configName), i18n("Restore")) == KMessageBox::Yes;
+    const int answer = KMessageBox::warningYesNo(mParentWidget,
+                                                 i18n("\"%1\" already exists. Do you want to overwrite it?", configName),
+                                                 i18n("Restore"),
+                                                 KStandardGuiItem::overwrite(),
+                                                 KStandardGuiItem::cancel());
+    return (answer == KMessageBox::Yes);
 }
 
 bool ImportExportProgressIndicatorGui::overwriteDirectoryMessageBox(const QString &directory) const
@@ -79,7 +87,12 @@ bool ImportExportProgressIndicatorGui::overwriteDirectoryMessageBox(const QStrin
     if (PimDataExportGlobalConfig::self()->alwaysOverrideDirectory()) {
         return true;
     }
-    return KMessageBox::warningYesNo(mParentWidget, i18n("Directory \"%1\" already exists. Do you want to overwrite it?", directory), i18n("Restore")) == KMessageBox::Yes;
+    const int answer = KMessageBox::warningYesNo(mParentWidget,
+                                                 i18n("Directory \"%1\" already exists. Do you want to overwrite it?", directory),
+                                                 i18n("Restore"),
+                                                 KStandardGuiItem::overwrite(),
+                                                 KStandardGuiItem::cancel());
+    return (answer == KMessageBox::Yes);
 }
 
 void ImportExportProgressIndicatorGui::showErrorMessage(const QString &message, const QString &title)
