@@ -27,6 +27,5 @@ public:
 
 private:
     QProgressDialog *mProgressDialog = nullptr;
-    QWidget *mParentWidget = nullptr;
+    QWidget *const mParentWidget;
 };
-
