@@ -5,10 +5,10 @@
 */
 
 #include "pimdatabackuprestoreui.h"
-#include "importexportprogressindicatorgui.h"
 #include "abstractimportexportjob.h"
-#include <KMessageBox>
+#include "importexportprogressindicatorgui.h"
 #include <KLocalizedString>
+#include <KMessageBox>
 
 PimDataBackupRestoreUI::PimDataBackupRestoreUI(QWidget *parentWidget, QObject *parent)
     : PimDataBackupRestore(parent)
@@ -22,10 +22,13 @@ PimDataBackupRestoreUI::~PimDataBackupRestoreUI()
 
 bool PimDataBackupRestoreUI::continueToRestore()
 {
-    if (KMessageBox::No
-        == KMessageBox::questionYesNo(mParentWidget,
-                                      i18n("The archive was created by a newer version of this program. It might contain additional data which will be skipped during import. Do you want to import it?"),
-                                      i18n("Not correct version"))) {
+    const int answer = KMessageBox::questionYesNo(mParentWidget,
+                                                  i18n("The archive was created by a newer version of this program. It might contain additional data which "
+                                                       "will be skipped during import. Do you want to import it?"),
+                                                  i18n("Not correct version"),
+                                                  KGuiItem(i18nc("@action:button", "Import"), QStringLiteral("document-import")),
+                                                  KStandardGuiItem::cancel());
+    if (answer == KMessageBox::No) {
         return false;
     }
     return true;
