@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef PIMDATABACKUPRESTOREUI_H
-#define PIMDATABACKUPRESTOREUI_H
+#pragma once
 
 #include "pimdatabackuprestore.h"
 
@@ -19,8 +18,7 @@ public:
 protected:
     Q_REQUIRED_RESULT bool continueToRestore() override;
     void addExportProgressIndicator() override;
-private:
-    QWidget *mParentWidget = nullptr;
-};
 
-#endif // PIMDATABACKUPRESTOREUI_H
+private:
+    QWidget *const mParentWidget;
+};
