@@ -4,13 +4,13 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "pimdatacommandlineoption.h"
+#include "pimdataexporter-version.h"
 #include "pimdataexporterwindow.h"
 #include "pimdataexportgui_debug.h"
-#include "pimdataexporter-version.h"
-#include <KLocalizedString>
 #include <KAboutData>
-#include <QCommandLineOption>
+#include <KLocalizedString>
 #include <QApplication>
+#include <QCommandLineOption>
 
 PimDataCommandLineOption::PimDataCommandLineOption(QObject *parent)
     : QObject(parent)
@@ -35,16 +35,21 @@ void PimDataCommandLineOption::slotActivateRequested(const QStringList &argument
 
 void PimDataCommandLineOption::createParser(const QApplication &app)
 {
-    KAboutData aboutData(QStringLiteral("pimdataexporter"), i18n("PIM Data Exporter"),
-                         QStringLiteral(PIMDATAEXPORTER_VERSION), i18n("PIM Data Exporter"), KAboutLicense::GPL_V2,
+    KAboutData aboutData(QStringLiteral("pimdataexporter"),
+                         i18n("PIM Data Exporter"),
+                         QStringLiteral(PIMDATAEXPORTER_VERSION),
+                         i18n("PIM Data Exporter"),
+                         KAboutLicense::GPL_V2,
                          i18n("Copyright © 2012-2021 pimdataexporter authors"));
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Maintainer"), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
     aboutData.setupCommandLine(&mParser);
-    mParser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("template"), i18n("Template file uses to define what data, settings to import or export"), QStringLiteral("file")));
-    mParser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("import"), i18n("Import the given file")));
-    mParser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("export"), i18n("Export the given file")));
-    mParser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("+[url]"), i18n("File or url. The user will be asked whether to import or export.")));
+    mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("template"),
+                                         i18n("Template file uses to define what data, settings to import or export"),
+                                         QStringLiteral("file")));
+    mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("import"), i18n("Import the given file")));
+    mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("export"), i18n("Export the given file")));
+    mParser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), i18n("File or url. The user will be asked whether to import or export.")));
 #ifdef WITH_KUSERFEEDBACK
     mParser.addOption(QCommandLineOption(QStringLiteral("feedback"), i18n("Lists the available options for user feedback")));
 #endif
