@@ -7,7 +7,8 @@
 #pragma once
 
 #include <QObject>
-namespace KUserFeedback {
+namespace KUserFeedback
+{
 class Provider;
 }
 class UserFeedBackManager : public QObject
@@ -20,6 +21,5 @@ public:
     KUserFeedback::Provider *userFeedbackProvider() const;
 
 private:
-    KUserFeedback::Provider *mUserFeedbackProvider = nullptr;
+    KUserFeedback::Provider *const mUserFeedbackProvider;
 };
-
