@@ -12,10 +12,10 @@
 
 LogWidget::LogWidget(QWidget *parent)
     : QWidget(parent)
+    , mCustomLogWidget(new PimCommon::CustomLogWidget(this))
 {
-  auto layout = new QHBoxLayout(this);
-  mCustomLogWidget = new PimCommon::CustomLogWidget(this);
-  layout->addWidget(mCustomLogWidget);
+    auto layout = new QHBoxLayout(this);
+    layout->addWidget(mCustomLogWidget);
 }
 
 LogWidget::~LogWidget()
