@@ -7,7 +7,8 @@
 #pragma once
 
 #include <QWidget>
-namespace PimCommon {
+namespace PimCommon
+{
 class CustomLogWidget;
 }
 
@@ -28,6 +29,5 @@ public:
     Q_REQUIRED_RESULT bool isEmpty() const;
 
 private:
-    PimCommon::CustomLogWidget *mCustomLogWidget = nullptr;
+    PimCommon::CustomLogWidget *const mCustomLogWidget;
 };
-
